{
  agenix,
  home-manager,
  lix-module,
  nixos-hardware,
  nur,
  pkgs,
  ...
}: {
  imports = [
    ./hardware-configuration.nix
    ./system.nix
    agenix.nixosModules.default
    home-manager.nixosModule
    lix-module.nixosModules.default
    nur.nixosModules.nur

    ./borg.nix
    ./gdm.nix
    ./pipewire.nix
    ./printer.nix
    ./sway.nix
    ./syncthing.nix
    ./tlp.nix

    ../../users/buffet
  ];

  age.identityPaths = ["/home/buffet/.ssh/id_agenix"];
  networking.hostName = "alice";

  users = {
    mutableUsers = false;
    users.root.hashedPassword = "!";
  };

  environment.systemPackages = with pkgs; [
    gitFull
    neovim
  ];

  fonts.packages = with pkgs; [
    apl386
    dejavu_fonts
    nasin-nanpa
    noto-fonts
    noto-fonts-cjk
  ];

  powerManagement.enable = true;
  systemd.coredump.enable = true;
  virtualisation.podman = {
    enable = true;
    autoPrune.enable = true;
  };

  hardware = {
    bluetooth.enable = true;
    system76.power-daemon.enable = true;
    uinput.enable = true;
  };

  services = {
    upower.enable = true;

    mullvad-vpn = {
      enable = true;
      package = pkgs.mullvad-vpn; # enable gui
    };

    udisks2 = {
      enable = true;
      mountOnMedia = true;
    };
  };
}
