{
  pkgs,
  nixpkgs,
  nixpkgs-unstable,
  nixos-hardware,
  ...
}: {
  imports = [
    nixos-hardware.nixosModules.lenovo-thinkpad-x270
  ];

  system.stateVersion = "23.11";

  time.timeZone = "Europe/Berlin";
  i18n.defaultLocale = "en_US.UTF-8";

  boot = {
    supportedFilesystems = ["bcachefs"];

    loader = {
      systemd-boot.enable = true;
      efi.canTouchEfiVariables = true;
    };
  };

  networking = {
    networkmanager.enable = true;
    nameservers = ["1.1.1.1"];
  };

  nix = {
    registry = {
      nixpkgs.flake = nixpkgs;
      nixpkgs-unstable.flake = nixpkgs-unstable;
    };

    settings = {
      auto-optimise-store = true;
      trusted-users = ["root"];

      substituters = [
        "https://cache.nixos.org/"
        "https://kitchen.cachix.org"
        "https://nix-community.cachix.org"
      ];

      trusted-public-keys = [
        "kitchen.cachix.org-1:6Re4jyiv2oURRRehWaktZ9eEcZpKd8g3v10R8jWsaD4="
        "nix-community.cachix.org-1:mB9FSh9qf2dCimDSUo8Zy7bkq5CX+/rkCWyvRCYg3Fs="
      ];
    };

    gc = {
      automatic = true;
      dates = "weekly";
      options = "--delete-older-than 30d";
    };

    extraOptions = ''
      experimental-features = nix-command flakes
    '';
  };

  assertions = [
    {
      assertion = -1 == builtins.compareVersions pkgs.linuxPackages.kernel.version "6.7.3";
      message = "default kernel has hit 6.7, change linuxPackages to default";
    }
  ];
}
